from risk import var_utils2 as vu2, var_utils as vu
import time

start0 = time.perf_counter()
result1 = vu2.get_cfalloc2(0.01,0.01,0.1, 0.1)
print(result1)
end0 = time.perf_counter()
print(f"Time required for all process to complete: {end0 - start0:0.6f} seconds")

start1 = time.perf_counter()
result2 = vu.get_cfalloc(0.01,0.01,0.1, 0.1)
print(result2)
end1 = time.perf_counter()
print(f"Time required for all process to complete: {end1 - start1:0.6f} seconds")

start2 = time.perf_counter()
result1 = vu.get_cfweight(1,3,2 )
print(result1)
end2 = time.perf_counter()
print(f"Time required for all process to complete: {end2 - start2:0.8f} seconds")


start3 = time.perf_counter()
result1 = vu2.get_cfweight2(1,3,2 )
print(result1)
end3 = time.perf_counter()
print(f"Time required for all process to complete: {end3 - start3:0.8f} seconds")


#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Fri Oct 30 13:36:21 2020

@author: RMS671214
"""
import time
from numpy import datetime64 as dt64
from nbutils.curvebootstrapping import df_st

# %%
rate_basis = "Simple"
day_count = "Actual/365"
bus_day = "No Adjustment"

rate ={'O/N': 2.30, '1W': 2.35, '1M': 2.45, '3M': 2.55, '6M': 2.65, '12M': 2.75}
date = dt64('2021-01-01', 'D')
x = 1000
rates = [rate for i in range(x)]
dates = [date for i in range(x)]

print(f"rates size is {len(rates)}")
start0 = time.perf_counter()
dfs = df_st(dates,rates,day_count, bus_day)
end0 = time.perf_counter()

print(f"Time taken is {end0-start0} seconds. Size is {len(dfs)}")





import numba
import time
from numpy import datetime64 as dt64, timedelta64 as td64
import numpy

sdate1 = '2021-01-01'
sdate2 = '2022-01-01'
date1 = dt64('2021-01-01')
date2 = dt64('2022-01-01')
nbdate1 = numba.types.NPDatetime('D')(date1)
nbdate2 = numba.types.NPDatetime('D')(date2)
print(type(nbdate2))
i = 1
t = 1

def differences(date1,date2):
    return (date2 - date1).astype('int')/365

start0 = time.perf_counter()
for x in range(t):
    test1 = differences(date1, date2)
end0 = time.perf_counter()
print(f"Time taken is for test1 {end0-start0} seconds: result {test1}")

@numba.njit(numba.types.NPTimedelta('D')(numba.types.NPDatetime('D'), 
numba.types.NPDatetime('D')), cache = True)
def numba_differences2(date1, date2):
    a = (date2 - date1)
    return a

start0 = time.perf_counter()
for x in range(t):
    test2 = numba_differences2(date1, date2)
end0 = time.perf_counter()
print(f"Time taken is for test2 {end0-start0} seconds: result {test2}")


td_ayear = numba.types.NPTimedelta('D')(365)
#print(td_ayear)
@numba.njit(numba.float64(numba.types.NPDatetime('D'), numba.types.NPDatetime('D'),
numba.types.NPTimedelta('D')), cache = True)
def numba_differences3(date1, date2, thetime):
    a = (date2 - date1)
    c = a/thetime
    return c

start0 = time.perf_counter()
for x in range(t):
    test2 = numba_differences3(date1, date2, td_ayear)
end0 = time.perf_counter()
print(f"Time taken for test3  is {end0-start0} seconds: result {test2}")

# cant work with array of datetime64
@numba.njit(numba.types.NPTimedelta('D')(numba.types.NPDatetime('D')[:], 
numba.types.NPDatetime('D')[:]), cache = True)
def numba_differences4(date1, date2):
    size = len(date1)
    for i in range(size):
        a = date2[i] - date1[i]
    
    return a

start0 = time.perf_counter()
nbdates1 = numpy.fromiter((date1 for x in range(t)), '<M8[D]')
nbdates2 = numpy.fromiter((date2 for x in range(t)), '<M8[D]')

test2 = numba_differences4(nbdates1, nbdates2)
end0 = time.perf_counter()
print(f"Time taken for test4 is {end0-start0} seconds: result {test2}")

datemonth = dt64('2021-01-05', 'M')
month  = td64(6,'M')

@numba.njit(numba.types.NPDatetime('M')(numba.types.NPDatetime('M'), 
numba.types.NPTimedelta('M')), cache = True)
#@numba.jit
def movedatebymonth(date1, month):
    return date1 + (month)


@numba.njit(numba.types.NPDatetime('M')(numba.types.NPDatetime('M'), 
numba.types.int64), cache = True)
#@numba.jit
def movedatebymonth2(date1, month):
    return date1 + numba.types.NPTimedelta('M')(month)

start0 = time.perf_counter()
testdatemonth = movedatebymonth2(datemonth, 6)
end0 = time.perf_counter()
print(f"Time taken for testdatemonth is {end0-start0} seconds: result {dt64(testdatemonth,'D') + 5}")



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Fri Oct 30 13:36:21 2020

@author: RMS671214
"""

from nbutils.nbcurves import generate_fulldf as gen_df
from numpy import datetime64 as dt64
import time

# %%
vdates = [dt64('2020-10-30')]
st_busday = 'Modified Following'
st_ratebasis = 'Simple'
st_daycount = 'Actual/365'
lt_busday = "No Adjustment"
lt_frequency =  "Semi-Annual"
lt_daycount = "Actual/Actual"

st_curves = [{'O/N': 2.30, '1W': 2.35, '1M': 2.45, '3M': 2.55,
                  '6M': 2.65}]
lt_curves = [{'1Y': 2.70, '2Y': 2.80, '3Y': 2.90,
                  '5Y': 3.00, '10Y': 3.10, '30Y': 3.25}]


start0 = time.perf_counter()
for i in range(100):
    dfs = gen_df(vdates, st_curves, st_daycount, st_busday,
                    st_ratebasis, lt_curves, lt_daycount,
                    lt_busday, frequency=6,
                    method="Forward from issue date",
                    holidays=[])
end0 = time.perf_counter()
print(f"Time taken is {end0-start0} seconds")
#print(f"Total time = {len(dfs)} and dfs = {dfs}")
#print(dfs)